pub struct TrialConfig {
pub trials: usize,
pub points_per_face: usize,
pub scale: f64,
pub noise_sigma: f64,
pub tolerance: f64,
pub initial_translation: f64,
pub initial_rotation: f64,
pub estimated_normals: bool,
pub seed: u64,
}Expand description
Experiment parameters.
Fields
trials: usizeHow many independent trials.
points_per_face: usizePoints per face of the scene.
scale: f64Characteristic size of the scene, metres.
noise_sigma: f64Standard deviation of the noise on source positions, metres.
tolerance: f64Required pose accuracy, metres, used for the classification.
initial_translation: f64Norm of the translational part of the initial perturbation, metres.
initial_rotation: f64Norm of the rotational part of the initial perturbation, radians.
estimated_normals: boolEstimate normals from neighbours instead of using analytical ones.
seed: u64Seed.